@@ -431,6 +431,13 @@ PyMODINIT_FUNC PyInit_pythonmonkey(void)
     return NULL;
   }
 
+  JS::RootedObject debuggerGlobal(GLOBAL_CX, JS_NewGlobalObject(GLOBAL_CX, &globalClass, nullptr, JS::FireOnNewGlobalHook, options));
+  {
+    JSAutoRealm r(GLOBAL_CX, debuggerGlobal);
+    JS_DefineProperty(GLOBAL_CX, debuggerGlobal, "mainGlobal", *global, JSPROP_READONLY);
+    JS_DefineDebuggerObject(GLOBAL_CX, debuggerGlobal);
+  }
+
   autoRealm = new JSAutoRealm(GLOBAL_CX, *global);
 
   if (!JS_DefineFunctions(GLOBAL_CX, *global, jsGlobalFunctions)) {
@@ -439,6 +446,7 @@ PyMODINIT_FUNC PyInit_pythonmonkey(void)
   }
 
   JS_SetGCCallback(GLOBAL_CX, handleSharedPythonMonkeyMemory, NULL);
+  JS_DefineProperty(GLOBAL_CX, *global, "debuggerGlobal", debuggerGlobal, JSPROP_READONLY);
 
   // XXX: SpiderMonkey bug???
   // In https://hg.mozilla.org/releases/mozilla-esr102/file/3b574e1/js/src/jit/CacheIR.cpp#l317, trying to use the callback returned by `js::GetDOMProxyShadowsCheck()` even it's unset (nullptr)
